loadResults: Loading the data produced from the Shiny App

Description Usage Arguments Value Examples

View source: R/loadResults.R

Description

Loading the data produced from the Shiny App

Usage

1
loadResults(outputDir, full_data)

Arguments

outputDir

A string containing the path to where the ShinyApp data has been stored.

Value

A dataframe containing the start and end times of the dive as well as the start and end times of the user-defined bottom phase. The dive number and the time stamp of when the bottom phase data had been saved are included as well.

Examples

1
loadResults("path/to/Shiny/data/ouputs/")

iamurphy/bustR documentation built on Aug. 8, 2021, 2:14 p.m.