Description Usage Arguments Value Examples
Loading the data produced from the Shiny App
1 | loadResults(outputDir, full_data)
|
outputDir |
A string containing the path to where the ShinyApp data has been stored. |
A dataframe containing the start and end times of the dive as well as the start and end times of the user-defined bottom phase. The dive number and the time stamp of when the bottom phase data had been saved are included as well.
1 | loadResults("path/to/Shiny/data/ouputs/")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.